<?php

namespace Drupal\pipedrive\Service;

use Drupal\Core\Form\FormStateInterface;

/**
 * Service for generating a form to allow fields mapping to Pipedrive.
 */
interface PipedriveEntityMappingFormServiceInterface {

  /**
   * Get a form to handle mapping editing.
   *
   * @param string $entity_type
   *   The entity type id.
   * @param string $bundle
   *   The bundle id.
   * @param array $defaults
   *   An array of default values.
   *
   * @return array
   *   The form definition.
   */
  public function getFieldMappingFormItem(
      $entity_type,
      $bundle = NULL,
      array $defaults = []
    );

  /**
   * Get the values from a form that been generated by getFieldMappingsFormItem.
   *
   * @param string $entity_type
   *   The entity type id.
   * @param string $bundle
   *   The bundle id.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state from which to extract values.
   *
   * @return array
   *   An array of key value pairs from the form for the mappings.
   */
  public function getFieldMappingFormValues(
    $entity_type,
    $bundle,
    FormStateInterface $form_state);

}
